import Component from '@glimmer/component';
import { type ModelsTableDataItem } from '../../../../types/models-table-data-item.type';
import { type CellEditToggleSignature } from '../../../../interfaces/components/models-table/themes/default/cell-edit-toggle-signature.interface';
export interface RowActionPayload {
    record: ModelsTableDataItem;
}
/**
 * Component for cells used as toggle for edit-mode.
 *
 * Properties and event-handlers from {@link DefaultTheme.Cell | Cell} are bound here
 *
 * Usage example:
 *
 * ```html
 * <ModelsTable
 *   @data={{this.data}}
 *   @columns={{this.columns}}
 *   @columnComponents={{hash
 *     editRow=(component
 *       "models-table/cell-edit-toggle"
 *       onSaveRow=this.onSaveRow
 *       onCancelRow=this.onCancelRow"
 *   )}}
 * />
 * ```
 *
 * ```js
 * import Controller from '@ember/controller';
 * import {action} from '@ember/object';
 *
 * export default class InLineEditController extends Controller {
 *
 *   data = [];
 *
 *   columns = [
 *     {propertyName: 'firstName'},
 *     {propertyName: 'lastName'},
 *     {
 *       title: 'Edit',
 *       component: 'editRow',
 *       editable: false // <--- IMPORTANT
 *     }
 *   ];
 *
 *   @action
 *   onSaveRow(param) {
 *     return param.record.save();
 *   }
 *
 *   @action
 *   onCancelRow({record}) {
 *     record.rollbackAttributes();
 *     return true;
 *   }
 * }
 * ```
 */
export default class CellEditToggle extends Component<CellEditToggleSignature> {
    protected onClick(event: Event): void;
    /**
     * Fires when "Save" button is clicked. Edit-mode for row is turned off
     *
     * @event saveClicked
     */
    protected saveClicked(): void;
    /**
     * Fires when "Edit" button is clicked. Edit-mode for row is turned on
     *
     * @event editClicked
     */
    protected editClicked(): void;
    /**
     * Fires when "Cancel Edit" button is clicked. Edit-mode for row is turned off
     *
     * @event cancelClicked
     */
    protected cancelClicked(): void;
}
//# sourceMappingURL=cell-edit-toggle.d.ts.map