import Component from '@glimmer/component';
import { type PaginationSimpleSignature } from '../../../../interfaces/components/models-table/themes/default/pagination-simple-signature.interface';
/**
 * Simple navigation (first, prev, next, last) used within {@link DefaultTheme.TableFooter | TableFooter} or {@link Core.ModelsTable | ModelsTable}.
 *
 * Usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.Footer as |Footer|>
 *     <Footer.PaginationSimple />
 *     {{! ... }}
 *   </MT.Footer>
 *   {{! .... }}
 * </ModelsTable>
 * ```
 *
 * Block usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.Footer as |Footer|>
 *     <Footer.PaginationSimple as |PS|>
 *       <button
 *         class="{{if PS.goToBackEnabled "enabled" "disabled"}} {{MT.themeInstance.buttonDefault}}"
 *         {{on "click" PS.goToFirst}}>
 *         <i class={{MT.themeInstance.navFirstIcon}}></i>
 *       </button>
 *       <button
 *         class="{{if PS.goToBackEnabled "enabled" "disabled"}} {{MT.themeInstance.buttonDefault}}"
 *         {{on "click" PS.goToPrev}}>
 *         <i class={{MT.themeInstance.navPrevIcon}}></i>
 *       </button>
 *       <button
 *         class="{{if PS.goToForwardEnabled "enabled" "disabled"}} {{MT.themeInstance.buttonDefault}}"
 *         {{on "click" PS.goToNext}}>
 *         <i class={{MT.themeInstance.navNextIcon}}></i>
 *       </button>
 *       <button
 *         class="{{if PS.goToForwardEnabled "enabled" "disabled"}} {{MT.themeInstance.buttonDefault}}"
 *         {{on "click" PS.goToLast}}>
 *         <i class={{MT.themeInstance.navLastIcon}}></i>
 *       </button>
 *       <PS.PageNumberSelect/>
 *     </Footer.PaginationSimple>
 *   </MT.Footer>
 * </ModelsTable>
 * ```
 * ModelsTablePaginationSimple yields references to the following contextual components:
 *
 * * {@link DefaultTheme.Select | PageNumberSelect} - selectbox with list of available pages
 *
 * References to the following properties are yielded:
 *
 * * {@link goToBackEnabled} - `true` is user is not in the first page
 * * {@link goToForwardEnabled} - `true` if user is not in the last page
 *
 * References to the following actions are yielded:
 *
 * * {@link DefaultTheme.PaginationSimpleArgs.goToPage | goToPage} - action to navigate user to the custom page
 * * {@link gotoFirst} - action to navigate user to the first page
 * * {@link gotoPrev} - action to navigate user to the previous page
 * * {@link gotoNext} - action to navigate user to the next page
 * * {@link gotoLast} - action to navigate user to the last page
 */
export default class PaginationSimple extends Component<PaginationSimpleSignature> {
    protected elementId: string;
    /**
     * Are buttons "Back" and "First" enabled
     *
     * @default false
     */
    get goToBackEnabled(): boolean;
    /**
     * Are buttons "Next" and "Last" enabled
     *
     * @default false
     */
    get goToForwardEnabled(): boolean;
    protected get inputId(): string;
    /**
     * @event gotoFirst
     */
    gotoFirst(e: Event): boolean;
    /**
     * @event gotoPrev
     */
    gotoPrev(e: Event): boolean;
    /**
     * @event gotoNext
     */
    gotoNext(e: Event): boolean;
    /**
     * @event gotoLast
     */
    gotoLast(e: Event): boolean;
    /**
     * @event goToPage
     */
    protected goToPage(pageNumber: string): void;
    /**
     * @event noop
     */
    protected noop(): void;
}
//# sourceMappingURL=pagination-simple.d.ts.map